==> haskell-deepseq-generics-0.2.0.0-1-i686.pkg.tar.xz: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deepseq-generics
version: 0.2.0.0
id: deepseq-generics-0.2.0.0-ESBROgKchbm3QXcQv2e7oG
key: deepseq-generics-0.2.0.0-ESBROgKchbm3QXcQv2e7oG
license: BSD3
copyright: 2012, Herbert Valerio Riedel
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/deepseq-generics
synopsis: GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.
    .
    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).
    .
    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.
    .
    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.
category: Control
author: Herbert Valerio Riedel
exposed: True
exposed-modules:
    Control.DeepSeq.Generics
abi: 2b0990d16b37dace4f1653f0e123a6a8
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/deepseq-generics-0.2.0.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/deepseq-generics-0.2.0.0
data-dir: /usr/share/i386-linux-ghc-8.0.1/deepseq-generics-0.2.0.0
hs-libraries: HSdeepseq-generics-0.2.0.0-ESBROgKchbm3QXcQv2e7oG
depends:
    base-4.9.0.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
haddock-interfaces: /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock
haddock-html: /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-deepseq-generics-0.2.0.0-2-i686.pkg.tar.xz: usr/share/haskell/register/haskell-deepseq-generics.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: deepseq-generics
version: 0.2.0.0
id: deepseq-generics-0.2.0.0-IjS8Jfo7YCzLKpV8N96gbz
key: deepseq-generics-0.2.0.0-IjS8Jfo7YCzLKpV8N96gbz
license: BSD3
copyright: 2012, Herbert Valerio Riedel
maintainer: hvr@gnu.org
homepage: https://github.com/hvr/deepseq-generics
synopsis: GHC.Generics-based Control.DeepSeq.rnf implementation
description:
    This package provides a "GHC.Generics"-based
    '\''Control.DeepSeq.Generics.genericRnf'\'' function which can be used
    for providing a '\''rnf'\'' implementation. See the documentation for
    the '\''genericRnf'\'' function in the "Control.DeepSeq.Generics" module
    to get started.
    .
    The original idea was pioneered in the @generic-deepseq@ package
    (see <http://www.haskell.org/pipermail/haskell-cafe/2012-February/099551.html>
    for more information).
    .
    This package differs from the @generic-deepseq@ package by working
    in combination with the existing @deepseq@ package as opposed to
    defining a conflicting drop-in replacement for @deepseq@'\''s
    @Control.DeepSeq@ module.
    .
    __Note__: The ability to auto-derive via "GHC.Generics" has been
    merged into @deepseq-1.4.0.0@. This package is now still useful
    for writing code that'\''s also compatible with older @deepseq@
    versions not yet providing "GHC.Generics"-support.
category: Control
author: Herbert Valerio Riedel
exposed: True
exposed-modules:
    Control.DeepSeq.Generics
abi: 9861dcfc96857850559d08302f0f7658
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/deepseq-generics-0.2.0.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/deepseq-generics-0.2.0.0
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/deepseq-generics-0.2.0.0
hs-libraries: HSdeepseq-generics-0.2.0.0-IjS8Jfo7YCzLKpV8N96gbz
depends:
    base-4.9.1.0 deepseq-1.4.2.0 ghc-prim-0.5.0.0
haddock-interfaces: /usr/share/doc/haskell-deepseq-generics/html/deepseq-generics.haddock
haddock-html: /usr/share/doc/haskell-deepseq-generics/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
